function [f coefs] = analytic(t,f)
%f = analytic(t,f);
%[f c] = analytic(t,f);
%
%analytic uses low-pass filter interpolation to return an analytic
%representation of f(t) as a sum of cosines. c are the frequency, amplitude
%and phase coefficients associated with each cosine term.
%
%The return variable f is a function handle. For any input vector t, f(t) 
%is an interpolation of the original vector f.

Nr = 32;
N = length(f);
mt = min(t);
rt = range(t);

K = ceil((N+1)/2);
F = fft(f);
F = F(1:K);

coefs = zeros(3,K);
coefs(1,:) = (1/rt)*(2*pi*(N-1)/N)*[0:K-1];
coefs(3,:) = mod(-(mt/rt)*(2*pi*(N-1)/N)*[0:K-1] + angle(F),2*pi);
coefs(2,:) = (1/N)*abs(F);
coefs(2,2:end-1) = 2*coefs(2,2:end-1);
if(isodd(N))
    coefs(2,end) = 2*coefs(2,end);
end

eqstr = '';
sp = '';
for k = 1:K
    wstr = num2str(coefs(1,k),Nr);
    astr = num2str(coefs(2,k),Nr);
    tstr = num2str(coefs(3,k),Nr);
    
    cosstr = [astr '*cos(' wstr '*t + ' tstr ')'];
    eqstr = [eqstr sp cosstr];
    sp = ' + ';
end
f = inline(eqstr);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%