function s = spiketrain(t,p)
%s = spiketrain(t,p)
%
%spiketrain creates a simulated spike train using a simple model.
%
%Variables:
%   t   :   A vector of time in seconds.
%   p   :   A period, in seconds.
%   s   :   A spike train.

t = t-min(t);
Nt = length(t);
Ns = ceil(range(t)/p);
s = zeros(1,Nt);
for k = 1:Ns
    s = s + spike(t-(k-1)*p);
end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function s = spike(t)
%s = spike(t)
%
%spike makes a single action potential. t is specified in seconds.

t = 6000*(t - 1e-3);
r = (1/250)*gampdf(6-t,20,1/5);
w = gampdf(t-pi+1,pi,1);
w = w./max(w);
a = raylpdf(t,2);
a = exp(-t);
s = a.*sin(w.*t) + r;
s = s./max(s);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function xi = fillin(x)
%xi = fillin(x)
%
%fillin uses interpollation to fill in a one-dimensional vector. 

x = makerow(x);
len = length(x);

ind = 1:length(x);
fnd = find(~isnan(x));
x = interp1(ind(fnd),x(fnd),ind);

x2 = x(find(~isnan(x)));
D = [x2(end)-x2(1)];
xL = x - D;
xR = x + D;

X = [xL x xR];
ind = find(~isnan(X));
X = X(ind);
Ind = [1:3*len];
ind = Ind(ind);

xi = interp1(ind,X,Ind);
xi = xi(len+1:2*len);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function x = makerow(x)
%y = makerow(x)

x = squeeze(x);
if(size(x,2) == 1) 
    x = x';
end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
