function [] = cmask(range,type)
%cmask([mmin mmax])
%%cmask([mmin mmax],type)
%
%cmask creates a color mask, in the specified range, where the color
%is set to the background color.  All changing of the caxis
%must be done before masking.  type is equal to either 'g' or 'hg' which
%specifies a gaussian mask or a half gaussian.

if(nargin < 2)
    type = 'g';
end
bc = get(gca,'Color');
c = caxis; map = colormap; len = size(map,1);
range = round(transform(range,c,[1 len]));
ind = 1:len; me = mean(range); st = (range(2)-range(1))/2;

if(isequal(type(1),'g'))
    g = gauss(ind,me,st);
else
    dist1 = abs(range(1)-1);
    dist2 = abs(len-range(2));
    if(dist1 < dist2)
        g = gauss(ind,1,2*st);
    else
        g = gauss(ind,len,2*st);
    end
end
g = transform(g,[min(g) max(g)],[0 1]);
warning off;
for i = 1:len
    try map(i,:) = g(i)*bc + (1-g(i))*map(i,:); end
end
warning on;
colormap(map);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function y = gauss(x,u,s)
%y = Gauss(x,u,s)
%
%Where u = mean (mu) and s = std (sigma)

y = (1/(s*sqrt(2*pi)))*exp(-1*((x-u).^2)/(2*(s^2)));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%