function map = ice()
%ice
%
%ice is a blue-cyan-white colormap. Type colormap(ice) to use it.

map = makecolormap([0 0 .5; 0 0 1; 0 1 1; 1 1 1]);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function map = makecolormap(colors,thickness)
%map = makecolormap(colors)
%map = makecolormap(colors,thickness)
%
%makecolormap takes a list of colors and returns a colormap.  Edge colors
%must be specified as the first and last in the colors.   Thickness is a color
%a parameter controlling how thick each color adds to the whole map.  It 
%defaults to 1.

if(nargin < 2)
    thickness = 1;
end
maplen = 64;
numcolors = size(colors,1);
maplen = (numcolors-1)*round((maplen-1)/(numcolors-1)) + 1;
space = (maplen-1)/(numcolors-1);

for n = 1:3
    if(numcolors == 2)
        curr = polyval(polyfit([1; maplen],colors(:,n),1),[1:64]');
    else
        curr = interp(colors(:,n),space,floor(numcolors/2)-1);
    end
    map(:,n) = curr(1:maplen);
end
map(find(map > 1)) = 1;
map(find(map < 0)) = 0;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%