function Y = HH(t,X,p)
%[dVdt dmdt dhdt dndt] = HH(t,[V m h n],p);
%
%HH implements the 4-dimensional Hodgkin-Huxley equations for a functional 
%input. This can be sent to the ode solver as an extra parameter:
%  
%  Xo = [0 0 0 0];
%  p = inline('.1*sin(t)','t');
%  
%  options = odeset;
%  [t S] = ode45(@HH,T,Xo,options,p);

V = X(1); 
m = X(2);
h = X(3);
n = X(4);

C = 1;
gNa = 120; 
gK = 36; 
gL = 0.3;
ENa = 115; 
EK = -12; 
EL = 10.6;

am = (25-V) ./ (10*(exp((25-V)./10)-1));
ah = 0.07*exp(-V/20);
an = (10-V) ./ (100*(exp((10-V)./10)-1));

bm = 4*exp(-V/18);
bh = 1 ./ (exp((30-V)./10)+1);
bn = 0.125*exp(-V/80);

INa = gNa*(m^3)*h*(V-ENa);
IK = gK*(n^4)*(V-EK);
IL = gL*(V-EL);

dmdt = am*(1-m) - bm*m;
dhdt = ah*(1-h) - bh*h;
dndt = an*(1-n) - bn*n;
dVdt = (-1/C)*(INa + IK + IL - gL*p(t));

Y = zeros(1,4)';
Y(1:4) = [dVdt dmdt dhdt dndt];
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%